@@ -23,7 +23,7 @@ class AppStarter:
         self.argv.pop(0)
 
         self.ScanApplication()
-        
+
         if(self.argv == []):
             print('Usage: python application.py <command>')
             sys.exit(0)
@@ -44,7 +44,7 @@ class AppStarter:
             self.UnknownCommand()
 
 
-    
+
     def ScanApplication(self):
         for page_r, page_d, page_f in os.walk(os.path.join(self.user_path), 'pages'):
             for page in page_d:
@@ -58,7 +58,7 @@ class AppStarter:
                                 else:
                                     if(page not in self.__LOADED_PAGES):
                                         self.__LOADED_PAGES.append(page)
-                        
+
                             for TAF in self.__TRUE_PAGE_FILES:
                                 if(TAF not in f and page not in self.__DAMAGED_APPS):
                                     self.__DAMAGED_APPS.append(page); self.__ERRORS += 1
@@ -66,12 +66,12 @@ class AppStarter:
                                 else:
                                     if(page not in self.__LOADED_PAGES):
                                         self.__LOADED_PAGES.append(page)
-                
+
         if(len(self.__DAMAGED_APPS) > 2):
             self.not_loaded_pages = str(', '.join(self.__DAMAGED_APPS[:2]))+' and '+str(len(self.__DAMAGED_APPS)-2)+' more pages'
         else:
             self.not_loaded_pages = str(', '.join(self.__DAMAGED_APPS))
-    
+
     def GetApplicationConfig(self):
         config = imp.load_source('application.config', os.path.join(self.user_path, 'config.py'))
         return_it = {'APP_PAGES':config.APP_PAGES, 'DEVELOPMENT_SERVER_PORT':config.DEVELOPMENT_SERVER_PORT}
@@ -105,7 +105,7 @@ class AppStarter:
 
                     with open(sub_path+'/'+template, 'w+') as template_file:
                         template_file.write(soup.prettify())
-                        
+
                     for static in section['statics']:
                         shutil.copy(
                             'pages/'+section['page_name']+'/static/'+static,
@@ -113,7 +113,7 @@ class AppStarter:
                         )
         except:
             pass
-        
+
 
     def RunServer(self):
         print(
@@ -130,24 +130,42 @@ class AppStarter:
                 sys.exit()
             for page in self.__LOADED_PAGES:
                 self.Load_Controllers(page, server.server_foldername) # Load Pages
-            subprocess.run('python -m http.server '+str(self.GetApplicationConfig()['DEVELOPMENT_SERVER_PORT'])+' --bind 127.0.0.1 --directory "'+str(os.path.join(self.user_path, 'pages', '.server'))+'"')
+            subprocess.run(
+            'python -m http.server '+str(self.GetApplicationConfig()['DEVELOPMENT_SERVER_PORT'])+' --bind 127.0.0.1 --directory "'+str(os.path.join(self.user_path, 'pages', '.server'))+'"',
+            shell=True
+            )
         except KeyboardInterrupt:
             server.Stop()
-            
+
     def UnknownCommand(self):
         print('Unknown command : '+str(self.argv[0]).title())
         sys.exit(0)
 
+    def RemoveDir(self, dir_):
+        dir_ = dir_.replace('\\', '/')
+        for r,d,f in os.walk(dir_):
+            for i in d:
+                self.RemoveDir(r+'/'+i)
+            for i in f:
+                i = i.replace('/', '')
+                os.unlink(r+'/'+i)
+            for i in d:
+                os.rmdir(r+'/'+i)
+
     def NewPage(self, page_name):
         if(os.path.isdir(os.path.join(self.user_path, 'pages', str(page_name)))):
             print('There is already a page with this name')
             sys.exit(0)
-        os.mkdir(os.path.join(self.user_path, 'pages', str(page_name)))
-        copy_tree(
-            os.path.join(self.module_path, 'app', 'Blank'),
-            os.path.join(self.user_path, 'pages', str(page_name))
-        )
-        with open(os.path.join(self.module_path, 'app', 'Blank', 'config.py'), 'r+') as config_text:
-            with open(os.path.join(self.user_path, 'pages', str(page_name), 'config.py'), 'w+') as config:
-                config.write(config_text.read().replace('[PAGE_NAME]', str(page_name)))
-        print(str(page_name).title()+' page created')
\ No newline at end of file
+        try:
+            os.mkdir(os.path.join(self.user_path, 'pages', str(page_name)))
+            copy_tree(
+                os.path.join(self.module_path, 'app', 'Blank'),
+                os.path.join(self.user_path, 'pages', str(page_name))
+            )
+            with open(os.path.join(self.module_path, 'app', 'Blank', 'config.py'), 'r+') as config_text:
+                with open(os.path.join(self.user_path, 'pages', str(page_name), 'config.py'), 'w+') as config:
+                    config.write(config_text.read().replace('[PAGE_NAME]', str(page_name)))
+            print(str(page_name).title()+' page created')
+        except:
+            self.RemoveDir(os.path.join(self.user_path, 'pages', str(page_name)))
+            print('Permission error to create new page')
